# RHK STM data analysis tools

Based on the spym project (version 0.9), for personal use in our research group. If you want to contribute, please do so in the main [rescipy project](https://github.com/rescipy-project/spym).

Documentation can be found here: https://zrbyte.github.io/rhkpy/

The package currently works with RHK software version 6 ('RHK_MinorVer' = 6). In the future older software versions will be supported.

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/zrbyte/rhkpy/HEAD)
